@@ -95,7 +95,6 @@ G_DEFINE_TYPE (GtrAssistant, gtr_assistant, GTK_TYPE_ASSISTANT)
   if (l)
     {
       GList *msg_list = NULL;
-      GList *l2 = NULL;
       GFile *location;
       GError *error = NULL;
       GtrPo *po;
@@ -109,16 +108,7 @@ G_DEFINE_TYPE (GtrAssistant, gtr_assistant, GTK_TYPE_ASSISTANT)
 
       msg_list = gtr_po_get_messages (po);
 
-      for (l2 = msg_list; l2; l2 = g_list_next (l2))
-        {
-          GtrMsg *msg;
-
-          msg = GTR_MSG (l2->data);
-          if (gtr_msg_is_translated (msg))
-            gtr_translation_memory_store (data->tm,
-                                          gtr_msg_get_msgid
-                                          (msg), gtr_msg_get_msgstr (msg));
-        }
+      gtr_translation_memory_store_list (data->tm, msg_list);
 
       g_object_unref (po);
     }
